@@ -1,3 +1,3 @@
 from .vehicule import Vehicule
 from .world import World
-from .avsim2D import AvSim2D
\ No newline at end of file
+#from .avsim2D import AvSim2D
\ No newline at end of file
